﻿using System;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using Infragistics.UltraChart.Core.Layers;
using Infragistics.UltraChart.Resources.Appearance;
using Infragistics.UltraChart.Shared.Styles;

namespace AGI.ServiceCallCenter.Model
{
    public partial class CompositeChart : Infragistics.Win.UltraWinChart.UltraChart
    {
        ChartArea _chartArea;
        ChartLayerAppearance _columnLayer;

        public CompositeChart()
        {
            InitializeComponent();
        }

        public CompositeChart(IContainer container)
        {
            container.Add(this);

            InitializeComponent();
        }

        public void SetColumnDataSource(DataTable dt, string title)
        {
            NumericSeries series;

            if (_columnLayer.Series.Count > 0)
                _columnLayer.Series.Clear();
            if (CompositeChart.Series.Count > 0)
                CompositeChart.Series.Clear();

            // first column of the table is the label column
            string labelColumn = dt.Columns[0].ColumnName;

            for (int i = 1; i < dt.Columns.Count; i++)
            {
                series = new NumericSeries();
                series.Data.DataSource = dt;
                series.Data.LabelColumn = labelColumn;
                series.Data.ValueColumn = dt.Columns[i].ColumnName;
                series.Label = dt.Columns[i].ColumnName;

                CompositeChart.Series.Add(series);
                _columnLayer.Series.Add(series);
            }
            DataBind();
            TitleBottom.Text = title;
        }

        private void UcCompositeChart_Load(object sender, EventArgs e)
        {
            this.ChartType = Infragistics.UltraChart.Shared.Styles.ChartType.Composite; //  ChartType.ColumnLineChart

            //  BorderStyle = System.Windows.Forms.BorderStyle.None;
            // Border.Color = Color.White;
            _chartArea = new ChartArea();
            CompositeChart.ChartAreas.Add(_chartArea);

            ColorModel.CustomPalette = new Color[]
           { Color.Green, Color.Blue, Color.Gold };


            //ColorModel.ColorBegin = Color.Blue;
            //ColorModel.ColorEnd = Color.Gold;

            //ColorModel.ColorBegin = Color.Blue;
            //ColorModel.ColorEnd = Color.Red ;


            ColorModel.ModelStyle = Infragistics.UltraChart.Shared.Styles.ColorModels.CustomLinear;//   = ColorModels.CustomLinear;
            Data.UseRowLabelsColumn = true;
            Tooltips.FormatString = "<SERIES_LABEL>, <ITEM_LABEL>: <DATA_VALUE:00.##>";
            BorderStyle = System.Windows.Forms.BorderStyle.None; // .None;
            
            AxisItem axisX = new AxisItem();
            axisX.OrientationType = AxisNumber.X_Axis;
            axisX.DataType = AxisDataType.String;
            axisX.SetLabelAxisType = SetLabelAxisType.GroupBySeries;
            axisX.Labels.ItemFormatString = "<ITEM_LABEL>";
            axisX.Labels.SeriesLabels.FormatString = "<SERIES_LABEL>";
            axisX.Labels.SeriesLabels.Visible = false;
            axisX.Labels.Orientation = TextOrientation.VerticalLeftFacing;
            axisX.Labels.ItemFormat = AxisItemLabelFormat.ItemLabel;
            axisX.LineThickness = 1;
            axisX.Extent = 45;

            AxisItem axisY = new AxisItem();
            axisY.OrientationType = AxisNumber.Y_Axis;
            axisY.DataType = AxisDataType.Numeric;
            axisY.Labels.ItemFormatString = "<DATA_VALUE:00>";
            axisY.LineThickness = 1;
            axisY.Extent = 10;

            AxisItem axisY2 = new AxisItem();
            axisY2.OrientationType = AxisNumber.Y2_Axis;
            axisY2.DataType = AxisDataType.Numeric;
            axisY2.Labels.ItemFormatString = "<DATA_VALUE:00>";
            axisY2.LineThickness = 1;
            axisY2.Extent = 10;
            axisY2.RangeType = AxisRangeType.Custom;
            axisY2.RangeMin = 1;
            axisY2.RangeMax = 2000;
            axisY2.TickmarkStyle = AxisTickStyle.Percentage;
            axisY2.TickmarkPercentage = 25;
            _chartArea.Axes.Add(axisX);
            _chartArea.Axes.Add(axisY);
            _chartArea.Axes.Add(axisY2);
            _columnLayer = new ChartLayerAppearance();
            _columnLayer.ChartType = ChartType.ColumnChart;
            _columnLayer.ChartArea = _chartArea;
            _columnLayer.SwapRowsAndColumns = true;
            
            _columnLayer.AxisX = axisX;
            _columnLayer.AxisY = axisY;
            _columnLayer.AxisY2 = axisY2;
            CompositeChart.ChartLayers.Add(_columnLayer);

            //CompositeChart.ChartAreas[0].Axes[0].LineColor = Color.Red ;
            
        }
    }
}
